import json

import sqlalchemy
import yaml
from sqlalchemy import TypeDecorator


class JSONEncodedDict(TypeDecorator):
    "Represents an immutable structure as a json-encoded string."

    impl = sqlalchemy.Text

    def process_bind_param(self, value, dialect):
        if value is not None:
            value = json.dumps(value)
        return value

    def process_result_value(self, value, dialect):
        if value is not None:
            value = json.loads(value)
        return value


class YAMLEncodedDict(TypeDecorator):
    "Represents an immutable structure as a yaml-encoded string."

    impl = sqlalchemy.Text

    def process_bind_param(self, value, dialect):
        if value is not None:
            value = yaml.safe_dump(value)
        return value

    def process_result_value(self, value, dialect):
        if value is not None:
            value = yaml.safe_load(value)
        return value
